==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/en_GB.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Files download limit",
    "File link share download limit" : "File link share download limit",
    "This app allows limiting the number of downloads for external link shares." : "This app offers the capability to restrict the number of downloads for external link shares.",
    "Limit downloads" : "Limit downloads",
    "Set download limit" : "Set download limit",
    "Setting a new limit will reset the download count" : "Setting a new limit will reset the download count",
    "The minimum limit is 1" : "The minimum limit is 1",
    "Failed to set download limit" : "Failed to set download limit",
    "Failed to remove download limit" : "Failed to remove download limit",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 remaining download allowed","{count} remaining downloads allowed"],
    "Download limit" : "Download limit",
    "Configure the default download limit for external shares." : "Configure the default download limit for external shares.",
    "Set default download limit" : "Set default download limit",
    "Failed to set default download limit" : "Failed to set default download limit",
    "You have reached the maximum amount of downloads allowed" : "You have reached the maximum amount of downloads allowed",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "This share has a limited number of downloads. Are you sure you want to trigger a new download?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/en_GB.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Files download limit",
    "File link share download limit" : "File link share download limit",
    "This app allows limiting the number of downloads for external link shares." : "This app offers the capability to restrict the number of downloads for external link shares.",
    "The minimum limit is 1" : "The minimum limit is 1",
    "Failed to set download limit" : "Failed to set download limit",
    "Failed to remove download limit" : "Failed to remove download limit",
    "Limit downloads" : "Limit downloads",
    "Set download limit" : "Set download limit",
    "Setting a new limit will reset the download count" : "Setting a new limit will reset the download count",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 remaining download allowed","{count} remaining downloads allowed"],
    "Download limit" : "Download limit",
    "Configure the default download limit for external shares." : "Configure the default download limit for external shares.",
    "Default download limit for external shares" : "Default download limit for external shares",
    "Set default download limit" : "Set default download limit",
    "You have reached the maximum amount of downloads allowed" : "You have reached the maximum amount of downloads allowed",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "This share has a limited number of downloads. Are you sure you want to trigger a new download?",
    "Failed to set default download limit" : "Failed to set default download limit",
    "Failed to remove default download limit" : "Failed to remove default download limit"
},
"nplurals=2; plural=(n != 1);");
